@@ -105,7 +105,7 @@ def define_auto(code):
             type_Var = var_dict.get(code2)
         var_dict[var_name] = (type_Var)
         var_dict_type[type_Var] = True
-        javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'   '+m)
+        javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'    '+m)
         var_list.append(var_name)
     return javacode
 class space:
@@ -123,7 +123,7 @@ class space:
         return code
     def getspace(string):
         global java_space
-        string += "   "*java_space
+        string += "    "*java_space
         return string
 def init():
     global playermoveevent1
@@ -698,7 +698,15 @@ def ProjectileHitEvent():
 #     m += i
 # file = open("hello.txt","w")
 # file.write(m)
-def make(*args,server,port,online):
+def make(server,**setting):
+    online = True
+    port = False
+    if server == True:
+        for h,s in setting.items():
+            if h == "port":
+                port = s
+            elif h == "online":
+                online = s 
     global Playerinclude
     global enable_space
     global addition_list
@@ -724,7 +732,6 @@ def make(*args,server,port,online):
     lines = file.readlines()
     global long
     for code in lines:
-        
         code = str(code)
         code = code.replace("when=", "")
         getvalue = distinguish_execution(code)
@@ -737,7 +744,11 @@ def make(*args,server,port,online):
                 howmany =1
             code = code.replace("    ","")
             code = code.replace("\n","")
-            if m == 'init':
+            if code.__contains__("if"):
+                raise Exception("I'm Sorry you can't use 'if' instead you can use 'while when():'"+'"'+filename+'", line '+str(long)+',')
+            elif code.__contains__("elif") or code.__contains__("else"):
+                raise Exception("I'm Sorry who can't use elif or else"+'"'+filename+'", line '+str(long)+',')
+            elif m == 'init':
                 del check_list[0] 
                 javacode = space.getspace(javacode)
                 javacode += 'public class Main extends JavaPlugin implements Listener{\n'
@@ -749,12 +760,11 @@ def make(*args,server,port,online):
                     if not (code.__contains__("get(")):
                         if not code[len(code)-2:len(code)] == "()":
                             # raise ValueError("you have to set () in '"+code+"'\n")
-                            global long
                             raise Exception('you should put () in "'+filename+'", line '+str(long)+',')
                 else:
                     if not var_list.__contains__("random"):
                         m = "public Random random = new Random();\n"
-                        javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'   '+m)
+                        javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'    '+m)
                         var_list.append("random")
                         addition_list.append("java.util.Random")
                     var = code.split("=")[0]
@@ -769,8 +779,8 @@ def make(*args,server,port,online):
                 code = code.replace("randint","nextInt")
                 code = code.replace("="," = ")
                 if code.__contains__("getItemInHand"):
-                    if not javacode.__contains__('@SuppressWarnings("deprecation")\n'+'   '+'public boolean'):
-                        javacode = javacode.replace('public boolean','@SuppressWarnings("deprecation")\n'+'   '+'public boolean')
+                    if not javacode.__contains__('@SuppressWarnings("deprecation")\n'+'    '+'public boolean'):
+                        javacode = javacode.replace('public boolean','@SuppressWarnings("deprecation")\n'+'    '+'public boolean')
                 code = code.replace("Command.sender()", "(Player) sender")
                 code = code.replace("Command.","")
                 code = code.replace("()","")
@@ -835,7 +845,7 @@ def make(*args,server,port,online):
                 test_value +=1
                 name = 'test'+str(test_value)
                 javacode += "    "*(java_space-1)
-                javacode += "   "
+                javacode += "    "
                 javacode += "@EventHandler\n"
                 code = code.replace(" ","")
                 code1 = code.replace('(', '')
@@ -884,7 +894,7 @@ def make(*args,server,port,online):
                         Playerinclude = True
                     m = 'public '+middle_part+' '+variable_name+';\n'
                 javacode = javacode.replace("public class Main extends JavaPlugin implements Listener{\n",
-                "public class Main extends JavaPlugin implements Listener{\n"+'   '+m)
+                "public class Main extends JavaPlugin implements Listener{\n"+'    '+m)
                 var_list.append(variable_name)
                 var_dict_type[middle_part] = True
             elif m == 'activity':
@@ -1064,18 +1074,17 @@ def make(*args,server,port,online):
                 java_space =1
                 python_space = 0
                 if not javacode.__contains__('public boolean '+name+'(CommandSender sender, Command cmd, String Label, String[] args) {\n'):
-                    javacode += '   '
+                    javacode += '    '
                     javacode += 'public boolean '+name+'(CommandSender sender, Command cmd, String Label, String[] args) {\n'
                 java_space +=1
                 python_space +=1
-                javacode += '   '*2+'if (Label.equalsIgnoreCase("'+code+'")) {\n'
+                javacode += '    '*2+'if (Label.equalsIgnoreCase("'+code+'")) {\n'
                 java_space +=1
                 howmany =1
                 if not addition_list.__contains__("org.bukkit.command.Command"): 
                     addition_list.append("org.bukkit.command.Command")
                     addition_list.append("org.bukkit.command.CommandSender")
                 r = 2*"    "
-                # javacode = javacode.replace('public void onEnable(){\n', 'public void onEnable(){\n'+r+'this.getCommand("'+code+'").setExecutor(this);\n')
                 file1 = open("data/src/main/resources/plugin.yml","r")
                 filek = open("data/src/main/resources/plugin.yml","a")
                 if not file1.readlines().__contains__("commands:\n"):
